@@ -147,7 +147,7 @@ re+=x[i];
 return(re);
 }
 
-inline double maxabs(double *x, double mu,int L){
+static inline double maxabs(double *x, double mu,int L){
 int i=0;double re=fabs(x[0]-mu);
 for(;i<L;i++){
 if (fabs(x[i]-mu)>re) re=fabs(x[i]-mu);
